@@ -23,27 +23,27 @@ class TestStatePermissions(TestCase):
         self.permission_2 = AuthUtils.get_permission_by_name(PERMISSION_2)
 
         # group
-        self.group_1 = Group.objects.create(name="Group 1")        
+        self.group_1 = Group.objects.create(name="Group 1")
         self.group_2 = Group.objects.create(name="Group 2")
 
         # state
-        self.state_1 = AuthUtils.get_member_state()        
+        self.state_1 = AuthUtils.get_member_state()
         self.state_2 = AuthUtils.create_state("Other State", 75)
-        
+
         # user
         self.user = AuthUtils.create_user("Bruce Wayne")
         self.main = AuthUtils.add_main_character_2(self.user, self.user.username, 123)
 
     def test_user_has_user_permissions(self):
         self.user.user_permissions.add(self.permission_1)
-        
+
         user = User.objects.get(pk=self.user.pk)
         self.assertTrue(user.has_perm(PERMISSION_1))
 
-    def test_user_has_group_permissions(self):        
+    def test_user_has_group_permissions(self):
         self.group_1.permissions.add(self.permission_1)
         self.user.groups.add(self.group_1)
-        
+
         user = User.objects.get(pk=self.user.pk)
         self.assertTrue(user.has_perm(PERMISSION_1))
 
@@ -55,7 +55,7 @@ class TestStatePermissions(TestCase):
         self.assertTrue(user.has_perm(PERMISSION_1))
 
     def test_when_user_changes_state_perms_change_accordingly(self):
-        self.state_1.permissions.add(self.permission_1)        
+        self.state_1.permissions.add(self.permission_1)
         self.state_1.member_characters.add(self.main)
         user = User.objects.get(pk=self.user.pk)
         self.assertTrue(user.has_perm(PERMISSION_1))
@@ -68,16 +68,16 @@ class TestStatePermissions(TestCase):
         self.assertTrue(user.has_perm(PERMISSION_2))
 
     def test_state_permissions_are_returned_for_current_user_object(self):
-        # verify state permissions are returns for the current user object 
-        # and not for it's instance in the database, which might be outdated        
+        # verify state permissions are returns for the current user object
+        # and not for it's instance in the database, which might be outdated
         self.state_1.permissions.add(self.permission_1)
-        self.state_2.permissions.add(self.permission_2)        
+        self.state_2.permissions.add(self.permission_2)
         self.state_1.member_characters.add(self.main)
         user = User.objects.get(pk=self.user.pk)
         user.profile.state = self.state_2
         self.assertFalse(user.has_perm(PERMISSION_1))
         self.assertTrue(user.has_perm(PERMISSION_2))
-    
+
 
 class TestAuthenticate(TestCase):
     @classmethod
@@ -114,12 +114,12 @@ class TestAuthenticate(TestCase):
     def test_authenticate_main_character(self):
         t = Token(character_id=self.main_character.character_id, character_owner_hash='1')
         user = StateBackend().authenticate(token=t)
-        self.assertEquals(user, self.user)
+        self.assertEqual(user, self.user)
 
     def test_authenticate_alt_character(self):
         t = Token(character_id=self.alt_character.character_id, character_owner_hash='2')
         user = StateBackend().authenticate(token=t)
-        self.assertEquals(user, self.user)
+        self.assertEqual(user, self.user)
 
     def test_authenticate_unclaimed_character(self):
         t = Token(character_id=self.unclaimed_character.character_id, character_name=self.unclaimed_character.character_name, character_owner_hash='3')
@@ -138,7 +138,7 @@ class TestAuthenticate(TestCase):
 
     def test_iterate_username(self):
         t = Token(character_id=self.unclaimed_character.character_id,
-                  character_name=self.unclaimed_character.character_name, character_owner_hash='3')
+                    character_name=self.unclaimed_character.character_name, character_owner_hash='3')
         username = StateBackend().authenticate(token=t).username
         t.character_owner_hash = '4'
         username_1 = StateBackend().authenticate(token=t).username
