@@ -1,5 +1,4 @@
-from django.conf.urls import url
-from django.contrib.auth.decorators import login_required
+from django.urls import path
 from django.views.generic.base import TemplateView
 
 from . import views
@@ -7,21 +6,21 @@ from . import views
 app_name = 'authentication'
 
 urlpatterns = [
-    url(r'^$', views.index, name='index'),
-    url(
-        r'^account/login/$',
+    path('', views.index, name='index'),
+    path(
+        'account/login/',
         TemplateView.as_view(template_name='public/login.html'),
         name='login'
     ),
-    url(
-        r'^account/characters/main/$',
+    path(
+        'account/characters/main/',
         views.main_character_change,
         name='change_main_character'
     ),
-    url(
-        r'^account/characters/add/$',
+    path(
+        'account/characters/add/',
         views.add_character,
         name='add_character'
     ),
-    url(r'^dashboard/$', views.dashboard, name='dashboard'),
+    path('dashboard/', views.dashboard, name='dashboard'),
 ]
