@@ -1,19 +1,6 @@
 from django.contrib.auth.models import Group
+
 from allianceauth.tests.auth_utils import AuthUtils
-from ..discord_client.tests import (    # noqa
-    TEST_GUILD_ID,
-    TEST_USER_ID,
-    TEST_USER_NAME,
-    TEST_USER_DISCRIMINATOR,
-    create_role,
-    ROLE_ALPHA,
-    ROLE_BRAVO,
-    ROLE_CHARLIE,
-    ROLE_CHARLIE_2,
-    ROLE_MIKE,
-    ALL_ROLES,
-    create_user_info
-)
 
 DEFAULT_AUTH_GROUP = 'Member'
 MODULE_PATH = 'allianceauth.services.modules.discord'
