@@ -26,16 +26,16 @@ class OpenfireService(ServicesHook):
         return _("Jabber")
 
     def delete_user(self, user, notify_user=False):
-        logger.debug('Deleting user %s %s account' % (user, self.name))
+        logger.debug(f'Deleting user {user} {self.name} account')
         return OpenfireTasks.delete_user(user, notify_user=notify_user)
 
     def validate_user(self, user):
-        logger.debug('Validating user %s %s account' % (user, self.name))
+        logger.debug(f'Validating user {user} {self.name} account')
         if OpenfireTasks.has_account(user) and not self.service_active_for_user(user):
             self.delete_user(user, notify_user=True)
 
     def update_groups(self, user):
-        logger.debug('Updating %s groups for %s' % (self.name, user))
+        logger.debug(f'Updating {self.name} groups for {user}')
         if OpenfireTasks.has_account(user):
             OpenfireTasks.update_groups.delay(user.pk)
 
@@ -74,10 +74,12 @@ def register_service():
 
 class JabberBroadcast(MenuItemHook):
     def __init__(self):
-        MenuItemHook.__init__(self,
-                              _('Jabber Broadcast'),
-                              'fas fa-bullhorn fa-fw',
-                              'openfire:broadcast')
+        MenuItemHook.__init__(
+            self,
+            _('Jabber Broadcast'),
+            'fas fa-bullhorn fa-fw',
+            'openfire:broadcast'
+        )
 
     def render(self, request):
         if request.user.has_perm('auth.jabber_broadcast') or request.user.has_perm('auth.jabber_broadcast_all'):
@@ -87,10 +89,12 @@ class JabberBroadcast(MenuItemHook):
 
 class FleetBroadcastFormatter(MenuItemHook):
     def __init__(self):
-        MenuItemHook.__init__(self,
-                              _('Fleet Broadcast Formatter'),
-                              'fas fa-space-shuttle fa-fw',
-                              'services:fleet_format_tool')
+        MenuItemHook.__init__(
+            self,
+            _('Fleet Broadcast Formatter'),
+            'fas fa-space-shuttle fa-fw',
+            'services:fleet_format_tool'
+        )
 
     def render(self, request):
         if request.user.has_perm('auth.jabber_broadcast') or request.user.has_perm('auth.jabber_broadcast_all'):
