@@ -3,7 +3,7 @@ import datetime
 from django import forms
 from django.utils import timezone
 from django.core.validators import MaxValueValidator, MinValueValidator
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from .models import Timer, TimerType
 
